pub enum ProjectOutputType {
SBOM,
InToto,
Unknown(String),
Custom(String),
}Expand description
The set of supported output types
Variants
SBOM
An output type for an SBOM from a project.
InToto
An output type for an in-toto attestation from a project.
Unknown(String)
An output type for an unknown output from a project.
Custom(String)
An output type for a custom output from a project.