pub struct ProjectOutputReference {
pub output_type: ProjectOutputType,
pub name: String,
pub labels: Vec<Label>,
}Expand description
A reference to the output of a project.
Fields
output_type: ProjectOutputTypeThe type of output to get from the project.
name: StringThe name of the output to get from the project.
labels: Vec<Label>Labels associated with the output